local _G = _G
module(...)
hosts_of_group = {
	name = "Hosts of group",
	tag = "nagios",
	order = 11,
	description = "Effectively the same as placing all the hosts of the hostgroup one by one.",
	hint = "Unfold host from group",
	links = {
		{ href = '/listview?q=[hosts] in "{{nagios_hostgroup}}"', title = "hostgroup details" },
		{ href = "/configuration/configure/hostgroup/{{nagios_hostgroup}}", title = "hostgroup configuration" },
		{ href = "/status/hostgroup/{{nagios_hostgroup}}?style=detail", title = "hostgroups services" }
	},
	rule = function(items, name, type)
		local ret = {}
		local h, hg, counth
		hg = _G.hostgroup(name)

		if hg ~= nil then
			counth = hg.num_hosts
		end

		if hg == nil or counth == 0 then
			return {{
				status = 3,
				msg = "Hostgroup not found",
				service_contacts = "*",
				service_contact_groups = "*",
				host_contacts = "*",
				host_contact_groups = "*"
			}}
		end
		local state, state_change
		local countu = 0
		local countd = 0
		for i,v in _G.ipairs(hg.members) do
			h = _G.host(v)
			if (type == "all") or (h.state_type == 1) then
				state = h.state
				state_change = h.last_state_change
			else
				state = h.last_hard_state
				state_change = h.last_hard_state_change
			end
			--there are not OK, WARNING and CRITICAL states in host, just UP and Down,
			--so convert WARNING to CRITICAL
			if state == 1 then
				state = 2
			end
			if state == 0 then
				countu = countu + 1
			elseif state == 2 then
				countd = countd +1
			end
			_G.table.insert(ret, {
				status = state,
				last_check = h.last_check,
				last_state_change = state_change,
				host_contacts = h.contacts,
				host_contact_groups = h.contact_groups,
				service_contacts = "*",
				service_contact_groups = "*"
			})
		end
		local worst_state = 0
		if countd > 0 then
			worst_state = 2
		end
		ret[1].worst_state = worst_state
		ret[1].msg = countu .. " hosts UP; " .. countd .. " hosts DOWN."
		return ret
	end,
	params = {
		{
			validation = {
				required = true,
				unique_in_scope = true
			},
			name = "nagios_hostgroup",
			label = "Host group",
			type = "nagios_hostgroup",
			hint = "Related host group name"
		}
	}
}
