local _G = _G
module(...)
services_of_group = {
	name = "Services of group",
	tag = "nagios",
	order = 8,
	description = "Effectively the same as placing all the services of the servicegroup one by one.",
	hint = "Unfold services from group",
	links = {
		{ href = '/listview?q=[services] in "{{nagios_servicegroup}}"', title = "servicegroup details" },
		{ href = "/configuration/configure/servicegroup/{{nagios_servicegroup}}", title = "servicegroup configuration" },
		{ href = "/extinfo/details?servicegroup={{nagios_servicegroup}}", title = "servicegroup services" }
	},
	rule = function(items, name, type)
		local ret = {}
		local cur_serv
		local sg = _G.servicegroup(name)
		local countsrv
		if sg ~= nil then
			countsrv = sg.num_services
		end
		if sg == nil or countsrv == 0 then
			return {{
				status = 3,
				msg = "Servicegroup not found",
				service_contacts = "*",
				service_contact_groups = "*",
				host_contacts = "*",
				host_contact_groups = "*"
			}}
		end
		local state, state_change
		local counto = 0
		local countw = 0
		local countc = 0
		for i,v in _G.ipairs(sg.members) do
			cur_serv = _G.host(v[1]):service(v[2])
			if (type == "all") or (cur_serv.state_type == 1) then
				state = cur_serv.state
				state_change = cur_serv.last_state_change
			else
				state = cur_serv.last_hard_state
				state_change = cur_serv.last_hard_state_change
			end
			if (state == 0) then
				counto = counto + 1
			elseif (state == 1) then
				countw = countw + 1
			elseif (state == 2) then
				countc = countc + 1
			end
			_G.table.insert(ret, {
				status = state,
				last_check = cur_serv.last_check,
				last_state_change = state_change,
				host_contacts = "*",
				host_contact_groups = "*",
				service_contacts = cur_serv.contacts,
				service_contact_groups = cur_serv.contact_groups
			})
		end
		local worst_state = 0
		if countc > 0 then
			worst_state = 2
		elseif countw > 0 then
			worst_state = 1
		end
		ret[1].worst_state = worst_state
		ret[1].msg = counto .. " OK;  " .. countw .. " WARNING;  " ..  countc .. " CRITICAL;  " .. sg.num_services .. " services total."
		return ret
	end,
	params = {
		{
			validation = {
				required = true,
				unique_in_scope = true
			},
			name = "nagios_servicegroup",
			label = "Service group",
			type = "nagios_servicegroup",
			hint = "Related service group name"
		}
	}
}
